@@ -1,6 +1,6 @@
-from . import kidney
-from . import monochromator
-from . import sample
+from . import Kidney
+from . import Monochromator
+from . import Sample
 from .virtualMACS import virtualMACS
 from .scripting import get_kidney_params
 from .scripting import get_mono_params
